/* $Id: common.h,v 1.36 2010/10/09 23:48:49 lamonte Exp $
 *
 * common.h
 *
 * Additional acknowledgements, news, and updates to the Qodem Project
 * are available at http://qodem.sourceforge.net .
 *
 * This module is licensed under the GNU General Public License Version 2.
 * Please see the file "COPYING" in this directory for more information
 * about the GNU General Public License Version 2.
 *
 *     Copyright (C) 2003  Kevin Lamonte
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 */

#ifndef __COMMON_H__
#define __COMMON_H__

/* Hans-Boehm garbage collector integration ------------------------------- */
#if defined(QODEM_USE_GC) && defined(HAVE_LIBGC)
#include <gc.h>

#ifdef DEBUG
#define Xmalloc(X, Y, Z)		GC_debug_malloc(X, Y, Z)
#define Xcalloc(X, Y, Z)		GC_debug_calloc(X, Y, Z)
#define Xrealloc(W, X, Y, Z)		GC_debug_realloc(W, X, Y, Z)
#define Xfree(X, Y, Z)			GC_debug_free(X)
#else
#define Xmalloc(X, Y, Z)		GC_malloc(X)
#define Xcalloc(X, Y, Z)		GC_calloc(X)
#define Xrealloc(W, X, Y, Z)		GC_realloc(W, X)
#define Xfree(X, Y, Z)			GC_free(X)
#endif /* DEBUG */
#else
#define Xmalloc(X, Y, Z)		malloc(X)
#define Xcalloc(X, Y, Z)		calloc(X)
#define Xrealloc(W, X, Y, Z)		realloc(W, X)
#define Xfree(X, Y, Z)			free(X)
#endif /* QODEM_USE_GC */

/* Includes --------------------------------------------------------------- */

#define _GNU_SOURCE
#include <wchar.h>

#include "config.h"

/* Defines ---------------------------------------------------------------- */
#define RELEASE
/* #undef RELEASE */

#define Q_VERSION		"0.3.2"
#define Q_AUTHOR		"Kevin Lamonte"

#ifdef RELEASE
#define Q_VERSION_BRANCH	"Production"
#else
#define Q_VERSION_BRANCH	"Development"
#endif /* RELEASE */

/* Exit codes */
#define EXIT_ERROR_SETLOCALE		12
#define EXIT_ERROR_SELECT_FAILED	20
#define EXIT_ERROR_COMMANDLINE		30
#define EXIT_HELP			1
#define EXIT_VERSION			2
#define EXIT_OK				0

#define TIME_STRING_LENGTH	64

/* HH:MM:SS */
#define SHORT_TIME_SIZE		9

/* Length of a command line string */
#define COMMAND_LINE_SIZE	1024

/* Maximum length of any filename */
#define FILENAME_SIZE		256

/* Maximum length of a message generated for a dialog box (e.g. file transfer dialog) */
#define DIALOG_MESSAGE_SIZE	128

/* Maximum length of a message generated for the session log */
#define SESSION_LOG_LINE_SIZE	512

/* Maximum line length in the options file */
#define OPTIONS_LINE_SIZE	128

/* Localization / Internationalization */
#if defined(HAVE_LOCALE_H) || defined(HAVE_LC_MESSAGES)
#include <locale.h>
#endif

#if ENABLE_NLS
#include <libintl.h>
#define _(String) gettext(String)
#else
#define _(String) (String)
#endif

/* boolean support */
#define Q_BOOL int
#define Q_FALSE 0
#define Q_TRUE 1

/* Globals ---------------------------------------------------------------- */

/* Functions -------------------------------------------------------------- */

extern char * Xstrdup(const char * ptr, const char * file, const int line);
extern wchar_t * Xwcsdup(const wchar_t * ptr, const char * file, const int line);
extern wchar_t * Xstring_to_wcsdup(const char * ptr, const char * file, const int line);

/* Function to clean out any characters waiting in stdin */
extern void purge_stdin();

#endif /* __COMMON_H__ */
